SearchResultItem class

Annotations
  • @freezed

Constructors

SearchResultItem({required int id, required String name, required String sort, required int key})
factory
SearchResultItem.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $SearchResultItemCopyWith<SearchResultItem>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
key int
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sort String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited